@@ -56,7 +56,7 @@
  ** Description: system environment, resource control and configuration details
 
 =end
-module FORMAT
+module SiSU_FormatAuthor
   class Author
     def initialize(author_param)
       @author_param=author_param
@@ -65,14 +65,14 @@ module FORMAT
       @authors,@author_array=[],[]
       authors=@author_param.scan(/[^;]+/)
       authors.each do |a|
-        a.strip!
+        a=a.strip
         if a =~/"(.+?)"/
           @authors << { the: $1 }
           @author_array << $1.upcase
         else #if a =~/,/
           x=a.scan(/[^,]+/)
-          x[0].strip!
-          x[1].strip! if x[1]
+          x[0]=x[0].strip
+          x[1]=x[1].strip if x[1]
           if x.length==1
             @authors << { the: x[0] }
             @author_array << x[0].upcase
