@@ -56,19 +56,19 @@
  ** Description: generates naive cgi search form for search of sisu database (pgsql sqlite)
 
 =end
-module  SiSU_CGI_pgsql                                                            #% database building documents
+module  SiSU_CGI_PgSQL                                                            #% database building documents
   require_relative 'sysenv'                             # sysenv.rb
   require_relative 'cgi_sql_common'                     # cgi_sql_common.rb
-    include SiSU_CGI_sql
-  class SiSU_search_pgsql < SiSU_CGI_common
+    include SiSU_CGI_SQL
+  class SearchPgSQL < CGI_Common
     def initialize(opt,webserv)
       @opt,@webserv=opt,webserv
-      @env=SiSU_Env::Info_env.new('',opt)
-      @sys=SiSU_Env::System_call.new
+      @env=SiSU_Env::InfoEnv.new('',opt)
+      @sys=SiSU_Env::SystemCall.new
       @image_src="#{@env.url.webserv_cgi}/_sisu/image_sys"
-      @common=SiSU_CGI_sql::SiSU_CGI_common.new(@webserv,@opt,@image_src,@env)
-      @db=SiSU_Env::Info_db.new
-      @cgi_file_name="#{Db[:name_prefix_db]}by_#{opt.dir_structure_by}_pgsql.cgi"
+      @common=SiSU_CGI_SQL::CGI_Common.new(@webserv,@opt,@image_src,@env)
+      @db=SiSU_Env::InfoDb.new
+      @cgi_file_name="#{Db[:name_prefix_db]}by_#{opt.dir_structure_by.to_s}_pgsql.cgi"
     end
     def pgsql
       serve=[]
@@ -82,7 +82,7 @@ module  SiSU_CGI_pgsql
           end
         else put "WARNING: no postgresql database available, (have you created one?)"
         end
-        serve.sort!
+        serve=serve.sort
         f1,f2,f3='','',''
         serve.each do |x|
           f1 << %{              <option value="#{Db[:name_prefix]}#{x}">#{x}</option>\n} unless x =~/apache|sisu\/image/ #check
@@ -140,7 +140,7 @@ module  SiSU_CGI_pgsql
     end
     def search_statement
       <<-'WOK_SQL'
-      class Dbi_search_string
+      class DBI_SearchString
         def initialize(l,t,q,cse=false)
           @l,@t,@q,@c=l,t,q,cse
         end
@@ -151,12 +151,12 @@ module  SiSU_CGI_pgsql
             elsif @q =~/\S+/;  unescaped_search=CGI.unescape(@q)
             end
             search_construct=[]
-            if @c
-              unescaped_search.gsub!(/\s*(AND|OR)\s*/,"' \) \\1 #{@l}~\( '")
-              unescaped_search.gsub!(/(.+)/,"#{@l}~\( '\\1' \)")
+            unescaped_search=if @c
+              unescaped_search.gsub(/\s*(AND|OR)\s*/,"' \) \\1 #{@l}~\( '").
+                gsub(/(.+)/,"#{@l}~\( '\\1' \)")
             else
-              unescaped_search.gsub!(/\s*(AND|OR)\s*/,"' \) \\1 #{@l}~*\( '")
-              unescaped_search.gsub!(/(.+)/,"#{@l}~*\( '\\1' \)")
+              unescaped_search.gsub(/\s*(AND|OR)\s*/,"' \) \\1 #{@l}~*\( '").
+                gsub(/(.+)/,"#{@l}~*\( '\\1' \)")
             end
             search_construct << unescaped_search
             search_construct=search_construct.join(' ')
@@ -173,11 +173,11 @@ module  SiSU_CGI_pgsql
       <<-'WOK_SQL'
           @search_text,@search_endnotes='',''
           search[:text].flatten.each {|x| @search_text << "#{x} AND " }
-          @search_text=@search_text.gsub!(/AND\s+$/m,'') #watch
-          @search_text.gsub!(/(doc_objects\.clean~[*]?\(\s*'[^']+'\s*\)\s+(?:(?:AND|OR)\s+doc_objects\.clean~[*]?\(\s*'[^']+'\s*\))+)/,'(\1)')
+          @search_text=@search_text.gsub(/AND\s+$/m,''). #watch
+            gsub(/(doc_objects\.clean~[*]?\(\s*'[^']+'\s*\)\s+(?:(?:AND|OR)\s+doc_objects\.clean~[*]?\(\s*'[^']+'\s*\))+)/,'(\1)')
           search[:endnotes].flatten.each {|x| @search_endnotes << "#{x} AND " }
-          @search_endnotes=@search_endnotes.gsub!(/AND\s+$/m,'') #watch
-          @search_endnotes.gsub!(/(endnotes\.clean~\(\s*'[^']+'\s*\)\s+(?:(?:AND|OR)\s+endnotes\.clean~\(\s*'[^']+'\s*\))+)/,'(\1)')
+          @search_endnotes=@search_endnotes.gsub(/AND\s+$/m,''). #watch
+            gsub(/(endnotes\.clean~\(\s*'[^']+'\s*\)\s+(?:(?:AND|OR)\s+endnotes\.clean~\(\s*'[^']+'\s*\))+)/,'(\1)')
         end
       WOK_SQL
     end
