@@ -56,8 +56,8 @@
  ** Description: generates naive cgi search form for search of sisu database (pgsql sqlite)
 
 =end
-module SiSU_CGI_sql
-  class SiSU_CGI_common
+module SiSU_CGI_SQL
+  class CGI_Common
     def initialize(webserv,opt,image_src,dir)
       @webserv,@opt,@image_src,@env=webserv,opt,image_src,dir
       @cmd=opt.cmd
@@ -230,7 +230,7 @@ module SiSU_CGI_sql
     end
     def search_request
       <<-'WOK_SQL'
-      class Search_request                                                       #% search_for
+      class SearchRequest                                                       #% search_for
         attr_accessor :text1,:fulltext,:keywords,:title,:author,:topic_register,:subject,:description,:publisher,:editor,:contributor,:date,:type,:format,:identifier,:source,:language,:relation,:coverage,:rights,:comment,:abstract,:owner,:date_created,:date_issued,:date_modified,:date_available,:date_valid,:filename
         def initialize(search_field='',q='')
           @search_field,@q=search_field,q
@@ -311,12 +311,10 @@ module SiSU_CGI_sql
             elsif @search_field =~m[:string];            m[:string].match(@search_field)[1]
             else
               str=m[:word].match(@search_field)[1]
-              str.gsub!(/[()]/,'')
+              str=str.gsub(/[()]/,'')
               str
             end
-            search_string.strip!
-            search_string.gsub!(/\s+/,'+')
-            search_string
+            search_string=search_string.strip.search_string.gsub(/\s+/,'+')
           #else
           #  "__"
           end
@@ -326,7 +324,7 @@ module SiSU_CGI_sql
     end
     def search_statement_common
       <<-'WOK_SQL'
-      class Dbi_search_statement
+      class DBI_SearchStatement
         attr_reader :text_search_flag,:sql_select_body_format,:sql_select_endnotes_format,:sql_offset,:sql_limit
         def initialize(conn,search_for,q,c)
           @conn=conn
@@ -336,114 +334,114 @@ module SiSU_CGI_sql
           #@offset+=@@limit
           search={ :text => [], :endnotes => [] }
           cse=(c =~/\S/) ? true : false
-          st=Dbi_search_string.new('doc_objects.clean',search_for.text1,q['s1'],cse).string
-          se=Dbi_search_string.new('endnotes.clean',search_for.text1,q['s1'],cse).string
+          st=DBI_SearchString.new('doc_objects.clean',search_for.text1,q['s1'],cse).string
+          se=DBI_SearchString.new('endnotes.clean',search_for.text1,q['s1'],cse).string
           @text_search_flag=st[:flag]
           if st[:flag]
             search[:text]                    << st[:search]
             search[:endnotes]                << se[:search]
           end
-          st=Dbi_search_string.new('metadata_and_text.fulltext',search_for.fulltext,q['ft'],cse).string
+          st=DBI_SearchString.new('metadata_and_text.fulltext',search_for.fulltext,q['ft'],cse).string
           if st[:flag]
             search[:text]                    << st[:search]
             search[:endnotes]                << st[:search]
           end
-          st=Dbi_search_string.new('metadata_and_text.classify_keywords',search_for.keywords,q['key'],cse).string
+          st=DBI_SearchString.new('metadata_and_text.classify_keywords',search_for.keywords,q['key'],cse).string
           if st[:flag]
             search[:text]                    << st[:search]
             search[:endnotes]                << st[:search]
           end
-          st=Dbi_search_string.new('metadata_and_text.title',search_for.title,q['ti'],cse).string
+          st=DBI_SearchString.new('metadata_and_text.title',search_for.title,q['ti'],cse).string
           if st[:flag]
             search[:text]                    << st[:search]
             search[:endnotes]                << st[:search]
           end
-          st=Dbi_search_string.new('metadata_and_text.creator_author',search_for.author,q['au'],cse).string
+          st=DBI_SearchString.new('metadata_and_text.creator_author',search_for.author,q['au'],cse).string
           if st[:flag]
             search[:text]                    << st[:search]
             search[:endnotes]                << st[:search]
           end
-          st=Dbi_search_string.new('metadata_and_text.classify_topic_register',search_for.topic_register,q['tr'],cse).string
+          st=DBI_SearchString.new('metadata_and_text.classify_topic_register',search_for.topic_register,q['tr'],cse).string
           if st[:flag]
             search[:text]                    << st[:search]
             search[:endnotes]                << st[:search]
           end
-          st=Dbi_search_string.new('metadata_and_text.classify_subject',search_for.subject,q['sj'],cse).string
+          st=DBI_SearchString.new('metadata_and_text.classify_subject',search_for.subject,q['sj'],cse).string
           if st[:flag]
             search[:text]                    << st[:search]
             search[:endnotes]                << st[:search]
           end
-          st=Dbi_search_string.new('metadata_and_text.notes_description',search_for.description,q['dsc'],cse).string
+          st=DBI_SearchString.new('metadata_and_text.notes_description',search_for.description,q['dsc'],cse).string
           if st[:flag]
             search[:text]                    << st[:search]
             search[:endnotes]                << st[:search]
           end
-          st=Dbi_search_string.new('metadata_and_text.publisher',search_for.publisher,q['pb'],cse).string
+          st=DBI_SearchString.new('metadata_and_text.publisher',search_for.publisher,q['pb'],cse).string
           if st[:flag]
             search[:text]                    << st[:search]
             search[:endnotes]                << st[:search]
           end
-          st=Dbi_search_string.new('metadata_and_text.creator_editor',search_for.editor,q['cntr'],cse).string
+          st=DBI_SearchString.new('metadata_and_text.creator_editor',search_for.editor,q['cntr'],cse).string
           if st[:flag]
             search[:text]                    << st[:search]
             search[:endnotes]                << st[:search]
           end
-          st=Dbi_search_string.new('metadata_and_text.creator_contributor',search_for.contributor,q['cntr'],cse).string
+          st=DBI_SearchString.new('metadata_and_text.creator_contributor',search_for.contributor,q['cntr'],cse).string
           if st[:flag]
             search[:text]                    << st[:search]
             search[:endnotes]                << st[:search]
           end
-          st=Dbi_search_string.new('metadata_and_text.date_published',search_for.date,q['dt'],cse).string
+          st=DBI_SearchString.new('metadata_and_text.date_published',search_for.date,q['dt'],cse).string
           if st[:flag]
             search[:text]                    << st[:search]
             search[:endnotes]                << st[:search]
           end
-          st=Dbi_search_string.new('metadata_and_text.classify_type',search_for.type,q['ty'],cse).string
+          st=DBI_SearchString.new('metadata_and_text.classify_type',search_for.type,q['ty'],cse).string
           if st[:flag]
             search[:text]                    << st[:search]
             search[:endnotes]                << st[:search]
           end
-          st=Dbi_search_string.new('metadata_and_text.classify_identifier',search_for.identifier,q['id'],cse).string
+          st=DBI_SearchString.new('metadata_and_text.classify_identifier',search_for.identifier,q['id'],cse).string
           if st[:flag]
             search[:text]                    << st[:search]
             search[:endnotes]                << st[:search]
           end
-          st=Dbi_search_string.new('metadata_and_text.original_source',search_for.source,q['src'],cse).string
+          st=DBI_SearchString.new('metadata_and_text.original_source',search_for.source,q['src'],cse).string
           if st[:flag]
             search[:text]                    << st[:search]
             search[:endnotes]                << st[:search]
           end
-          st=Dbi_search_string.new('metadata_and_text.language_document_char',search_for.language,q['lang'],cse).string
+          st=DBI_SearchString.new('metadata_and_text.language_document_char',search_for.language,q['lang'],cse).string
           if st[:flag]
             search[:text]                    << st[:search]
             search[:endnotes]                << st[:search]
           end
-          st=Dbi_search_string.new('metadata_and_text.classify_relation',search_for.relation,q['rel'],cse).string
+          st=DBI_SearchString.new('metadata_and_text.classify_relation',search_for.relation,q['rel'],cse).string
           if st[:flag]
             search[:text]                    << st[:search]
             search[:endnotes]                << st[:search]
           end
-          st=Dbi_search_string.new('metadata_and_text.classify_coverage',search_for.coverage,q['cov'],cse).string
+          st=DBI_SearchString.new('metadata_and_text.classify_coverage',search_for.coverage,q['cov'],cse).string
           if st[:flag]
             search[:text]                    << st[:search]
             search[:endnotes]                << st[:search]
           end
-          st=Dbi_search_string.new('metadata_and_text.rights_all',search_for.rights,q['cr'],cse).string
+          st=DBI_SearchString.new('metadata_and_text.rights_all',search_for.rights,q['cr'],cse).string
           if st[:flag]
             search[:text]                    << st[:search]
             search[:endnotes]                << st[:search]
           end
-          st=Dbi_search_string.new('metadata_and_text.notes_comment',search_for.comment,q['co'],cse).string
+          st=DBI_SearchString.new('metadata_and_text.notes_comment',search_for.comment,q['co'],cse).string
           if st[:flag]
             search[:text]                    << st[:search]
             search[:endnotes]                << st[:search]
           end
-          st=Dbi_search_string.new('metadata_and_text.notes_abstract',search_for.abstract,q['ab'],cse).string
+          st=DBI_SearchString.new('metadata_and_text.notes_abstract',search_for.abstract,q['ab'],cse).string
           if st[:flag]
             search[:text]                    << st[:search]
             search[:endnotes]                << st[:search]
           end
-          st=Dbi_search_string.new('metadata_and_text.src_filename',search_for.filename,q['fns'],cse).string
+          st=DBI_SearchString.new('metadata_and_text.src_filename',search_for.filename,q['fns'],cse).string
           if st[:flag]
             search[:text]                    << st[:search]
             search[:endnotes]                << st[:search]
@@ -539,7 +537,7 @@ module SiSU_CGI_sql
       WOK_SQL
     end
     def tail
-      v=SiSU_Env::Info_version.instance.get_version
+      v=SiSU_Env::InfoVersion.instance.get_version
       <<-WOK_SQL
       def tail
         <<-'WOK'
@@ -703,7 +701,7 @@ module SiSU_CGI_sql
     def main2
       <<-'WOK_SQL'
           search_field=cgi['find'] if cgi['find'] # =~/\S+/
-          @search_for=Search_request.new(search_field,q) #.analyze               #% search_for
+          @search_for=SearchRequest.new(search_field,q) #.analyze               #% search_for
                                                                                  #% searches
           #Canned_search.new(@base,@search_for.text1,cgi)
           if @search_for.text1=~/\S+/ or @search_for.fulltext=~/\S+/ or @search_for.author=~/\S+/ or @search_for.topic_register=~/\S+/  #and search_field =~/\S/
@@ -756,13 +754,13 @@ module SiSU_CGI_sql
           elsif checked_all =~/checked/ or checked_url =~/checked/
             canned_search=@@canned_search_url.scan(/(?:s1|ft|au|ti|fns|tr)=[^&]+/)
             af=canned_search.join('; ')
-            af.gsub!(/s1=/,'text: ')
-            af.gsub!(/ft=/,'fulltxt: ')
-            af.gsub!(/au=/,'author: ')
-            af.gsub!(/ti=/,'title: ')
-            af.gsub!(/fns=/,'filename: ')
-            af.gsub!(/tr=/,'topic_register: ')
-            af.gsub!(/%2B/,' ')
+            af=af.gsub(/s1=/,'text: ').
+              gsub(/ft=/,'fulltxt: ').
+              gsub(/au=/,'author: ').
+              gsub(/ti=/,'title: ').
+              gsub(/fns=/,'filename: ').
+              gsub(/tr=/,'topic_register: ').
+              gsub(/%2B/,' ')
             analyze_format=af
             st=af.split(/\s*;\s*/)
             search_field=st.join("\n")
@@ -819,7 +817,7 @@ module SiSU_CGI_sql
             @search[:endnotes]<<%{endnotes.clean~*'#{CGI.unescape(s1)}'}
           end
           #% dbi_request
-          dbi_statement=Dbi_search_statement.new(@conn,@search_for,q,checked_case)
+          dbi_statement=DBI_SearchStatement.new(@conn,@search_for,q,checked_case)
           @text_search_flag=false
           @text_search_flag=dbi_statement.text_search_flag
           s_contents=dbi_statement.contents
@@ -843,7 +841,7 @@ module SiSU_CGI_sql
     end
     def dir_structure
       case @opt.dir_structure_by
-      when /language/
+      when :language
         <<-'WOK_SQL'
           def path_manifest(fn,ln=nil)
             "#{@hostpath}/#{ln}/manifest/#{fn}.html"
@@ -864,7 +862,7 @@ module SiSU_CGI_sql
             "#{@hostpath}/#{ln}/html/#{fn}.html"
           end
         WOK_SQL
-      when /filetype/
+      when :filetype
         <<-'WOK_SQL'
           def path_manifest(fn,ln=nil)
             "#{@hostpath}/manifest/#{fn}.#{ln}.html"
@@ -916,7 +914,7 @@ module SiSU_CGI_sql
             file_suffix=c['src_filename'][/.+?\.(_?sst|ssm)$/,1]
             lang=if location =~ /\S+?~(\S\S\S?)$/
               l=location[/\S+?~(\S\S\S?)$/,1]
-              location.gsub!(/(\S+?)~\S\S\S?/,'\1')
+              location=location.gsub(/(\S+?)~\S\S\S?/,'\1')
               l=".#{l}"
             else ''
             end
@@ -1008,7 +1006,7 @@ module SiSU_CGI_sql
             file_suffix=e['src_filename'][/.+?\.(_?sst|ssm)$/,1]
             lang=if location =~ /\S+?~(\S\S\S?)$/
               l=location[/\S+?~(\S\S\S?)$/,1]
-              location.gsub!(/(\S+?)~\S\S\S?/,'\1')
+              location=location.gsub(/(\S+?)~\S\S\S?/,'\1')
               l=".#{l}"
             else ''
             end
