@@ -57,7 +57,7 @@
     output generators [requires kirbybase]
 
 =end
-module SiSU_character_encode
+module SiSU_CharacterEncode
   require 'kirbybase'
   require_relative 'sysenv'                             # sysenv.rb
   class Characters
@@ -73,7 +73,7 @@ module SiSU_character_encode
       @ce_tbl=@db.create_table.documents(:character_encoding, :glyph,:String, :dec,:Integer, :hex,:String, :rb,:String, :html,:String, :html_name,:String, :tex,:String, :tex_licr,:String, :tex_alt,:String, :name,:String)
     end
     def db
-      x=Character_encoding.new.table
+      x=CharacterEncoding.new.table
       #x.each {|y| puts y[2].inspect}
       x.each do |c|
         #puts "#{c[0]}, #{c[1]}, #{c[2]}, #{c[3]}, #{c[4]}, #{c[5]}, #{c[6]}, #{c[7]}, #{c[8]}, #{c[9]}"
@@ -138,7 +138,7 @@ module SiSU_character_encode
       end
     end
   end
-  class Character_encoding
+  class CharacterEncoding
     def table
       x=[]
 #:glyph, :dec,:hex,  :rb,            :xml ,   :html_name,  :tex,    :tex_licr,         :tex_alt,          :name
