@@ -59,9 +59,9 @@
 =end
 module SiSU_Assemble
   require_relative 'sysenv'                             # sysenv.rb
-  class Remote_image
+  class RemoteImage
     def initialize
-      @env=SiSU_Env::Info_env.new
+      @env=SiSU_Env::InfoEnv.new
     end
     def image(dir)
       images=[]
@@ -82,7 +82,7 @@ module SiSU_Assemble
       end
       output_path="#{@env.path.webserv}/#{@env.path.stub_pwd}/_sisu/image_external"
       FileUtils::mkdir_p(output_path) unless FileTest.directory?(output_path)
-      SiSU_Env::System_call.new("#{path}/*",output_path,'q').rsync
+      SiSU_Env::SystemCall.new("#{path}/*",output_path,'q').rsync
     end
     def download_doc_skin(doc_skin) #first element in array is source url
       path="#{@env.processing_path.processing}/external_document/skin/doc"
@@ -104,14 +104,20 @@ module SiSU_Assemble
     @@imager={}
     def initialize(opt)
       @opt=opt
-      @env=SiSU_Env::Info_env.new
+      @env=SiSU_Env::InfoEnv.new
     end
     def read
       begin
-        @fns_array=IO.readlines(@opt.fns,'')
+        pwd=Dir.pwd
+        Dir.chdir(@opt.f_pth[:pth])
+        @fns_array=IO.readlines(@opt.fno,'')
         assembled=insertions?
         write(assembled)
-      rescue; SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
+        Dir.chdir(pwd)
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       ensure
       end
     end
@@ -161,11 +167,11 @@ module SiSU_Assemble
         end
         if not @code_flag \
         and i !~/^%+\s/
-          i.gsub!(/^([123]|:?[ABC])~\? /,'% [conditional heading:] \1~ ')            #off conditional heading (consider syntax)
+          i=i.gsub(/^([123]|:?[ABC])~\? /,'% [conditional heading:] \1~ ')            #off conditional heading (consider syntax)
           if i =~/^@\S+?:/
-            i.gsub!(/\n/m,"\n%  ")
-            i.gsub!(/\n%\s+$/m,'')
-            i.gsub!(/^@\S+?:/m,"\n% [imported header:] ")                          #off imported headers
+            i=i.gsub(/\n/m,"\n%  ").
+              gsub(/\n%\s+$/m,'').
+              gsub(/^@\S+?:/m,"\n% [imported header:] ")                          #off imported headers
           end
         end
         file[:prepared] << i
@@ -176,8 +182,7 @@ module SiSU_Assemble
       end
       file[:prepared] << "\n% end import" << "\n\n"
       if file[:images].length > 0
-        file[:images].flatten!
-        file[:images].uniq!
+        file[:images]=file[:images].flatten.uniq
         file[:images].delete_if {|x| x =~/https?:\/\// }
       end
       file
@@ -185,7 +190,7 @@ module SiSU_Assemble
     def insertions?
       data=@fns_array
       tuned_file,imagedir=[],[]
-      SiSU_Screen::Ansi.new(@opt.cmd,'Composite Document',"[#{@opt.f_pth[:lng_is]}] #{@opt.fns}").grey_title_hi unless @opt.cmd =~/q/
+      SiSU_Screen::Ansi.new(@opt.cmd,'Composite Document',"[#{@opt.f_pth[:lng_is]}] #{@opt.fno}").grey_title_hi unless @opt.cmd =~/q/
       para=data.each do |para|
         if para =~/^<<\s+(\S+?\.ss[it])$/ \
         or para =~/^<<\{(\S+?\.ss[it])\}$/ \
@@ -218,39 +223,40 @@ module SiSU_Assemble
           end
         else tuned_file << para
         end
-        tuned_file.flatten!
-        tuned_file.compact!
+        tuned_file=tuned_file.flatten.compact
       end
       if @@imager.length >0
         @@imager.each do |d,i|
-          i.flatten!
-          i.uniq!
+          i=i.flatten.uniq
           image_info=d + i
-          download_images(mage_info.flatten)
+          download_images(image_info.flatten)
         end
       end
       tuned_file
     end
   end
-  class Composite_file_list
+  class CompositeFileList
     @@imager={}
     def initialize(opt)
       @opt=opt
-      @env=SiSU_Env::Info_env.new
+      @env=SiSU_Env::InfoEnv.new
     end
     def read
       begin
         @opt.fns=@opt.fns.gsub(/\.ssm\.sst$/,'.ssm') #FIX earlier, hub
         @fns_array=IO.readlines(@opt.fns,'')
         files=insertions?
-      rescue; SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       ensure
       end
     end
     def insertions?
       data=@fns_array
       tuned_file,imagedir=[],[]
-      SiSU_Screen::Ansi.new(@opt.cmd,'Composite Document',@opt.fns).grey_title_hi unless @opt.cmd =~/q/
+      SiSU_Screen::Ansi.new(@opt.cmd,'Composite Document',@opt.fno).grey_title_hi unless @opt.cmd =~/q/
       @ssm=[@opt.fns]
       para=data.each do |para|
         if para =~/^<<\s+(\S+?\.ss[it])$/
