@@ -79,7 +79,7 @@ module SiSU_Concordance
         unless @md.opt.cmd =~/q/
           tool=(@md.opt.cmd =~/[MVv]/) \
           ? "#{@env.program.web_browser} #{@md.file.output_path.html_concordance.dir}/#{@md.file.base_filename.html_concordance}"
-          : "[#{@opt.f_pth[:lng_is]}] #{@opt.fns}"
+          : "[#{@opt.f_pth[:lng_is]}] #{@opt.fno}"
           @md.opt.cmd=~/[MVvz]/ \
           ? SiSU_Screen::Ansi.new(@opt.cmd,"Concordance",tool).grey_title_hi
           : SiSU_Screen::Ansi.new(@opt.cmd,'Concordance',tool).green_title_hi
@@ -95,7 +95,10 @@ module SiSU_Concordance
           SiSU_Screen::Ansi.new(@md.opt.cmd,"wc (word count) is off, concordance will be processed for all files including those over the max set size of: #{wordmax} words").warn unless @md.opt.cmd =~/q/
           SiSU_Concordance::Source::Words.new(@particulars).songsheet
         end
-      rescue; SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       ensure
       end
     end
@@ -214,7 +217,10 @@ WOK
           @alph=SiSU_i18n::Alphabet.new(@md.opt.lng).hash_arrays
           @alphlst=SiSU_i18n::Alphabet.new(@md.opt.lng).hash_strings
           @rgx_scanlist=%r{#{Mx[:fa_italics_o]}[#{@alphlst[:l]}#{@alphlst[:u]}0-9"\s]{2,12}#{Mx[:fa_italics_c]}|#{Mx[:fa_bold_o]}[#{@alphlst[:l]}#{@alphlst[:u]}0-9"\s]{2,12}#{Mx[:fa_bold_c]}|(?:https?|file)://\S+|<\S+?>|[#{@alphlst[:l]}#{@alphlst[:u]}]+|\w+}mi
-        rescue; SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error
+        rescue
+          SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+            __LINE__.to_s + ':' + __FILE__
+          end
         end
       end
       def songsheet
@@ -222,7 +228,10 @@ WOK
           FileUtils::mkdir_p(@file.output_path.html_concordance.dir) unless FileTest.directory?(@file.output_path.html_concordance.dir)
           @file_concordance=File.open(@file.place_file.html_concordance.dir,'w')
           map_para
-        rescue; SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error
+        rescue
+          SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+            __LINE__.to_s + ':' + __FILE__
+          end
         ensure
           @file_concordance.close
         end
