@@ -242,6 +242,9 @@ DISABLE={
     ncx_navpoint_unique_id:  true,
   },
 }
+DEVELOPER={
+  maintenance:               :false,
+}
 __END__
 consider:
   〔comment〕
@@ -273,8 +276,8 @@ puts "#{__FILE__} #{__LINE__} #{o.inspect}"
 puts __FILE__ + ' ' + __LINE__.to_s + '-->  ' + o.inspect
 puts %{-\t#{__FILE__}::#{__LINE__}::#{caller}:\n"#{name}"}
 p "\t" + txt.obj + " << #{__FILE__} #{__LINE__} >>"
-p (__FILE__ + ' ' + __LINE__.to_s + '--> ' + dob.inspect) if dob.is=='heading'
-data.each {|o| p (__FILE__ + ' ' + __LINE__.to_s + '--> ' + o.inspect) if o.is=='heading'}
+p (__FILE__ + ' ' + __LINE__.to_s + '--> ' + dob.inspect) if dob.is==:heading
+data.each {|o| p (__FILE__ + ' ' + __LINE__.to_s + '--> ' + o.inspect) if o.is==:heading}
 puts "#{__FILE__} #{__LINE__} #{para}" if @opt.cmd =~/M/
 puts "#{__FILE__} #{__LINE__} #{t_o}" if @opt.cmd =~/M/
  dr ┌  9484   dR ┍  9485   Dr ┎  9486   DR ┏  9487   dl ┐  9488   dL ┑  9489   Dl ┒  9490   LD ┓  9491  ur └  9492   uR ┕  9493   Ur ┖  9494   UR ┗  9495   ul ┘  9496   uL ┙  9497   Ul ┚  9498   UL ┛  9499   vr ├
