@@ -117,7 +117,10 @@ module SiSU_DAL
         ? @fnx
         : @opt.fns
         create_dal
-      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@@fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@@fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       ensure
         SiSU_DAL::Instantiate.new
       end
@@ -132,8 +135,13 @@ module SiSU_DAL
           : @opt.fns
           @@dal_array=[]
         end
-        dal=(@@dal_array.empty?) ? read_fnc : @@dal_array.dup
-      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
+        dal=(@@dal_array.empty?) \
+        ? read_fnc
+        : @@dal_array.dup
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       ensure
         SiSU_DAL::Instantiate.new
       end
@@ -149,7 +157,10 @@ module SiSU_DAL
           @@idx_arr[:sst]=[]
         end
         dal=(@@idx_arr[:sst].empty?) ? read_idx_sst : @@idx_arr[:sst].dup #check
-      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       ensure
         SiSU_DAL::Instantiate.new
       end
@@ -165,7 +176,10 @@ module SiSU_DAL
           @@idx_arr[:tex]=[]
         end
         dal=(@@idx_arr[:tex].empty?) ? read_idx_tex : @@idx_arr[:tex].dup #check
-      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       ensure
         SiSU_DAL::Instantiate.new
       end
@@ -181,7 +195,10 @@ module SiSU_DAL
           @@idx_arr[:html]=[]
         end
         dal=(@@idx_arr[:html].empty?) ? read_idx_html : @@idx_arr[:html].dup
-      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       ensure
         SiSU_DAL::Instantiate.new
       end
@@ -197,7 +214,10 @@ module SiSU_DAL
           @@idx_arr[:xthml]=[]
         end
         dal=(@@idx_arr[:xhtml].empty?) ? read_idx_xhtml : @@idx_arr[:xhtml].dup
-      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       ensure
         SiSU_DAL::Instantiate.new
       end
@@ -213,7 +233,10 @@ module SiSU_DAL
           @@map_arr[:nametags]=[]
         end
         dal=(@@map_arr[:nametags].empty?) ? read_map_nametags : @@map_arr[:nametags].dup
-      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       ensure
         SiSU_DAL::Instantiate.new
       end
@@ -229,7 +252,10 @@ module SiSU_DAL
           @@map_arr[:ocn_htmlseg]=[]
         end
         dal=(@@map_arr[:ocn_htmlseg].empty?) ? read_map_ocn_htmlseg : @@map_arr[:ocn_htmlseg].dup
-      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       ensure
         SiSU_DAL::Instantiate.new
       end
@@ -240,7 +266,7 @@ module SiSU_DAL
       unless @opt.cmd =~/q/
         tell=(@opt.cmd=~/[vVM]/) \
         ? SiSU_Screen::Ansi.new(@opt.cmd,'Document Abstraction')
-        : SiSU_Screen::Ansi.new(@opt.cmd,'Document Abstraction',"[#{@opt.f_pth[:lng_is]}] #{@opt.fns}")
+        : SiSU_Screen::Ansi.new(@opt.cmd,'Document Abstraction',"[#{@opt.f_pth[:lng_is]}] #{@opt.fno}")
         tell.green_title_hi
       end
       fn=(@fnx && @fnx =~/\.ss[tmi]$/) \
