@@ -56,7 +56,7 @@
  ** Description: system environment, resource control and configuration details
 
 =end
-module SiSU_endnotes
+module SiSU_DAL_Endnotes
   class Endnotes
     def initialize(md,data,endnote_array=nil)
       @md,@data,@endnote_array=md,data,endnote_array
@@ -69,17 +69,17 @@ module SiSU_endnotes
       data.each do |dob|
                                                                                # manually numbered endnotes <!e(\d)!> <!e_(\d)!> -->
         if @md.opt.mod.inspect =~/--no-asterisk|--no-annotate/
-          dob.obj.gsub!(/#{Mx[:en_b_o]}\s.+?#{Mx[:en_b_c]}/,'')
+          dob.obj=dob.obj.gsub(/#{Mx[:en_b_o]}\s.+?#{Mx[:en_b_c]}/,'')
         end
         if @md.opt.mod.inspect =~/--no-dagger|--no-annotate/
-          dob.obj.gsub!(/#{Mx[:en_b_o]}[+]\s.+?#{Mx[:en_b_c]}/,'')
+          dob.obj=dob.obj.gsub(/#{Mx[:en_b_o]}[+]\s.+?#{Mx[:en_b_c]}/,'')
         end
-        if defined? dob.obj \
-        and defined? dob.is \
-        and dob.is !~/^code/
+        if (defined? dob.obj) \
+        && (defined? dob.is) \
+        && dob.is !=:code
           case dob.obj                                                         # auto-numbered endnotes <!e!> <!e_!> -->
           when /#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}|#{Mx[:en_b_o]}[*+]\s+.+?#{Mx[:en_b_c]}/
-            dob.obj.gsub!(/\s*(#{Mx[:en_a_c]}|#{Mx[:en_b_c]})/,' \1')          # required 2003w31
+            dob.obj=dob.obj.gsub(/\s*(#{Mx[:en_a_c]}|#{Mx[:en_b_c]})/,' \1')          # required 2003w31
             word_mode=dob.obj.scan(/\S+/m)
             word_mode=endnote_call_number(word_mode)
             dob.obj=word_mode.join(' ')
