@@ -56,13 +56,13 @@
  ** Description: system environment, resource control and configuration details
 
 =end
-module SiSU_insertions
+module SiSU_DAL_Insertions
   class Insertions
     def initialize(md,data)
       @md,@data=md,data
     end
     def output_filetypes_in_cmd(cmd_shortcut,lnk=nil) #make list of file types in shortcut command (as configured), e.g. when sisu -3 is used
-      cf_defaults=SiSU_Env::Info_processing_flag.new
+      cf_defaults=SiSU_Env::InfoProcessingFlag.new
       cmd_list=case cmd_shortcut.inspect
       when /0/; cf_defaults.cf_0
       when /1/; cf_defaults.cf_1
@@ -141,7 +141,7 @@ module SiSU_insertions
       def xml_dom
         "#{@base_path}/xml/#{@linked_doc}.xml"
       end
-      def txt 
+      def txt
         "#{@base_path}/txt/#{@linked_doc}.txt"
       end
       def digest
@@ -241,7 +241,7 @@ module SiSU_insertions
       def xml_dom
         "#{@base_path}/scroll.#{@lng}.dom.xml"
       end
-      def txt 
+      def txt
         "#{@base_path}/plain.#{@lng}.txt"
       end
       def digest
@@ -270,17 +270,17 @@ module SiSU_insertions
         and not codeblock_ \
         and para =~/\{(?:~\^\s+)?(.+?)\s\[(?:\d(?:[sS]*))\]\}(?:\.\.\/\S+?\/|\S+?\.ss[tm]\b)/
           txt,cmd,source,linked_doc,note,manifest=nil,nil,nil,nil,nil,nil
-          @u=SiSU_Env::Info_env.new.url
+          @u=SiSU_Env::InfoEnv.new.url
           pre=txt=cmd=source=linked_doc=note=''
           if defined? @u.remote
             if /(?<pre>.+?)\{(?<txt>.+?)\s\[(?<cmd>\d[sS]*)\]\}(?<source>(?<linked_doc>\S+?)\.ss[tm]\b)(?<note>.*)/m =~ para
-              pre.strip!
+              pre=pre.strip
             elsif /\{(?<txt>.+?)\s\[(?<cmd>\d[sS]*)\]\}(?<source>(?<linked_doc>\S+?)\.ss[tm]\b)(?<note>.*)/m =~ para
             end
-            if linked_doc =~ /(\S+?)\/(\S+)/ 
+            if linked_doc =~ /(\S+?)\/(\S+)/
               linked_doc,linked_doc_lang=$1,$2
             else
-              linked_doc,linked_doc_lang=linked_doc,@md.opt.lng_base 
+              linked_doc,linked_doc_lang=linked_doc,@md.opt.lng_base
             end
           else
             puts "error, does currently support relative paths (reltive paths were removed, as had problems for citation, and was not suited to all output types should possibly reconsider) #{__FILE__} #{__LINE__}"
@@ -289,7 +289,7 @@ module SiSU_insertions
           end
           lnk={}
           case @md.opt.dir_structure_by
-          when /language/
+          when :language
             lnk={
               manifest:         by_language(linked_doc,linked_doc_lang).manifest,
               html_toc:         by_language(linked_doc,linked_doc_lang).html_toc,
@@ -307,7 +307,7 @@ module SiSU_insertions
               sisupod:          by_language(linked_doc,linked_doc_lang,source).sisupod,
               source:           by_language(linked_doc,linked_doc_lang,source).source,
             }
-          when /filetype/
+          when :filetype
             lnk={
               manifest:         by_filetype(linked_doc,linked_doc_lang).manifest,
               html_toc:         by_filetype(linked_doc,linked_doc_lang).html_toc,
