@@ -56,7 +56,7 @@
  ** Description: system environment, resource control and configuration details
 
 =end
-module SiSU_images
+module SiSU_DAL_Images
   class Images
     #require 'RMagick'
     #include Magick
@@ -67,7 +67,7 @@ module SiSU_images
       data=@data
       tuned_file=[]
       @rmgk=false
-      imagemagick_=true      #imagemagick_=SiSU_Env::Info_settings.new.program?('rmagick')
+      imagemagick_=true      #imagemagick_=SiSU_Env::InfoSettings.new.program?('rmagick')
       if imagemagick_
         begin
           @rmgk=SiSU_Env::Load.new('RMagick').prog
@@ -80,8 +80,8 @@ module SiSU_images
         end
       end
       data.each do |dob|
-        unless dob.is =~/^table/
-          dob.obj.strip!
+        unless dob.is ==:table
+          dob.obj=dob.obj.strip
           if dob.obj =~/#{Mx[:lnk_o]}\s*\S+\.(?:png|jpg|gif)(?:\s*|\s+.+)?#{Mx[:lnk_c]}(?:#{Mx[:url_o]}\S+?#{Mx[:url_c]}|image)/
             if dob.obj !~/#{Mx[:lnk_o]}\s*\S+\.(?:png|jpg|gif)\s+\d+x\d+/
               m=/#{Mx[:lnk_o]}\s*(\S+\.(?:png|jpg|gif))/
@@ -89,7 +89,7 @@ module SiSU_images
                 imgs=dob.obj.scan(m).flatten
                 img_col=img_row=nil
                 images=imgs.each do |image|
-                  dir=SiSU_Env::Info_env.new(@md.fns)
+                  dir=SiSU_Env::InfoEnv.new(@md.fns)
                   path_image=[dir.path.image_source_include_local,dir.path.image_source_include_remote,dir.path.image_source_include]
                   image_path=nil
                   path_image.each do |img_pth|
@@ -104,8 +104,8 @@ module SiSU_images
                       if @md.opt.cmd =~/[vVM]/
                         SiSU_Screen::Ansi.new(@md.opt.cmd,'RMagick not present, will attempt to use imagemagick (identify) directly').warn
                       end
-                      imgk=SiSU_Env::System_call.new.imagemagick
-                      gmgk=SiSU_Env::System_call.new.graphicksmagick
+                      imgk=SiSU_Env::SystemCall.new.imagemagick
+                      gmgk=SiSU_Env::SystemCall.new.graphicksmagick
                       if imgk or gmgk
                         if imgk
                           imgsys=`identify #{image_path}/#{image}`.strip                           #system call
@@ -133,8 +133,8 @@ module SiSU_images
                         img_col=((1.00*img_row/row)*col).round
                       end
                     end
-                    dob.obj.gsub!(/(#{image})/,"#{image} #{img_col}x#{img_row}")
-                  else dob.obj.gsub!(/#{Mx[:lnk_o]}\s*(\S+)\.(png|jpg|gif).+?#{Mx[:lnk_c]}(#{Mx[:url_o]}\S+?#{Mx[:url_c]}|image)/,'[ \1 (\2 missing) ]')
+                    dob.obj=dob.obj.gsub(/(#{image})/,"#{image} #{img_col}x#{img_row}")
+                  else dob.obj=dob.obj.gsub(/#{Mx[:lnk_o]}\s*(\S+)\.(png|jpg|gif).+?#{Mx[:lnk_c]}(#{Mx[:url_o]}\S+?#{Mx[:url_c]}|image)/,'[ \1 (\2 missing) ]')
                   end
                 end
               else
@@ -144,7 +144,9 @@ module SiSU_images
               end
             end
           end
-          dob.obj.gsub!(/(#{Mx[:lnk_o]})\s*(\S+\.(?:png|jpg|gif))\s+/i,'\1\2 ') if dob.obj =~/#{Mx[:lnk_o]}\s*\S+\.(?:png|jpg|gif).+?#{Mx[:lnk_c]}(?:#{Mx[:url_o]}\S+?#{Mx[:url_c]}|image)/
+          if dob.obj =~/#{Mx[:lnk_o]}\s*\S+\.(?:png|jpg|gif).+?#{Mx[:lnk_c]}(?:#{Mx[:url_o]}\S+?#{Mx[:url_c]}|image)/
+            dob.obj=dob.obj.gsub(/(#{Mx[:lnk_o]})\s*(\S+\.(?:png|jpg|gif))\s+/i,'\1\2 ')
+          end
         end
         tuned_file << dob unless dob.nil?
       end
