@@ -57,7 +57,7 @@
     sqlite
 
 =end
-module  SiSU_DB_DBI
+module  SiSU_DbDBI
   require_relative 'db_columns'                                             # db_columns.rb
   require_relative 'db_tests'                                               # db_tests.rb
   require_relative 'db_create'                                              # db_create.rb
@@ -67,27 +67,27 @@ module  SiSU_DB_DBI
   require_relative 'db_remove'                                              # db_remove.rb
   require_relative 'db_load_tuple'                                          # db_load_tuple.rb
   require_relative 'db_import'                                              # db_import.rb
-  class Column_size < SiSU_DB_columns::Column_size                             # db_columns.rb
+  class ColumnSize < SiSU_DbColumns::ColumnSize                             # db_columns.rb
   end
-  class Test < SiSU_DB_tests::Test                                             # db_tests.rb
+  class Test < SiSU_DbTests::Test                                           # db_tests.rb
   end
-  class Create <SiSU_DB_create::Create                                         # db_create.rb
+  class Create <SiSU_DbCreate::Create                                       # db_create.rb
   end
-  class Case <SiSU_DB_select::Case                                             # db_select.rb
+  class Case <SiSU_DbSelect::Case                                           # db_select.rb
   end
-  class Index <SiSU_DB_index::Index                                            # db_indexes.rb
+  class Index <SiSU_DbIndex::Index                                          # db_indexes.rb
   end
-  class Drop <SiSU_DB_drop::Drop                                               # db_drop.rb
+  class Drop <SiSU_DbDrop::Drop                                             # db_drop.rb
   end
-  class Remove <SiSU_DB_remove::Remove                                         # db_remove.rb
+  class Remove <SiSU_DbRemove::Remove                                       # db_remove.rb
   end
-  class Load_documents <SiSU_DB_tuple::Load_documents                          # db_load_tuple.rb
+  class LoadDocuments <SiSU_DbTuple::LoadDocuments                          # db_load_tuple.rb
   end
-  class Load_metadata <SiSU_DB_tuple::Load_metadata                            # db_load_tuple.rb
+  class LoadMetadata <SiSU_DbTuple::LoadMetadata                            # db_load_tuple.rb
   end
-  class Load_urls <SiSU_DB_tuple::Load_urls                                    # db_update urls
+  class LoadUrls <SiSU_DbTuple::LoadUrls                                    # db_update urls
   end
-  class Import <SiSU_DB_import::Import #<SiSU_DB::Column_size                  # db_import.rb
+  class Import <SiSU_DbImport::Import #<SiSU_DB::ColumnSize                  # db_import.rb
   end
 end
 __END__
