@@ -168,7 +168,9 @@ module SiSU_DbImport
           puts "Error code: #{e.err}"
           puts "Error message: #{e.errstr}"
           puts "Error SQLSTATE: #{e.state}"
-          SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
+          SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+            __LINE__.to_s + ':' + __FILE__
+          end
           sqlfn="#{@env.processing_path.sql}/#{@md.fnb}.sql"
           sql=File.new(sqlfn,'w')
           t_d.each {|i| sql.puts i}
@@ -179,7 +181,9 @@ module SiSU_DbImport
             puts "#{__FILE__}:#{__LINE__}"
           end
         rescue
-          SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
+          SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+            __LINE__.to_s + ':' + __FILE__
+          end
           sqlfn="#{@env.processing_path.sql}/#{@md.fnb}.sql"
           sql=File.new(sqlfn,'w')
           t_d.each {|i| sql.puts i}
