@@ -57,13 +57,13 @@
     sqlite
 
 =end
-module SiSU_DB_remove
+module SiSU_DbRemove
   class Remove
     def initialize(opt,conn,file,sql_type)
       @opt,@conn,@file,@sql_type=opt,conn,file,sql_type
       @md=SiSU_Param::Parameters.new(@opt).get
       @fnb=@md.fnb
-      @db=SiSU_Env::Info_db.new
+      @db=SiSU_Env::InfoDb.new
     end
     def remove
       driver_sqlite3=if @sql_type=='sqlite'
