@@ -121,7 +121,10 @@ module SiSU_DbSelect
             @sdb.create_table.endnotes_plus
             @sdb.create_table.urls
             @sdb_index.create_indexes
-          rescue;  SiSU_Errors::InfoError.new($!,$@,'-D').error; @sdb.output_dir?
+          rescue
+            SiSU_Errors::InfoError.new($!,$@,'-D').error; @sdb.output_dir? do
+              __LINE__.to_s + ':' + __FILE__
+            end
           end
         when /^--createtables?$/
           @sdb.output_dir?
@@ -198,9 +201,9 @@ module SiSU_DbSelect
         when /^--(?:db=)?(?:(?:sq)?lite|pg(?:sql)?|my(?:sql)?)$/
         when /^--(?:v\d+|dev)$/
         else
-          help=SiSU_Help::Help.new
-          help.summary
-          help.commands
+          #help=SiSU_Help::Help.new
+          #help.summary
+          #help.commands
         end
         if @opt.cmd =~/M/ \
         and @opt.cmd  =~/d/
