@@ -126,11 +126,13 @@ module  SiSU_DBI
       when /pg/;     read_psql
       when /sqlite/; read_sqlite
       end
-      SiSU_Screen::Ansi.new(@opt.cmd,"DBI (#{@sql_type}) #{@opt.mod}",@opt.fns).dbi_title unless @opt.cmd =~/q/
+      SiSU_Screen::Ansi.new(@opt.cmd,"DBI (#{@sql_type}) #{@opt.mod}",@opt.fno).dbi_title unless @opt.cmd =~/q/
       begin
         SiSU_DbDBI::Case.new(@opt,@conn,@sql_type).cases
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@cf,@opt.fns).error
+        SiSU_Errors::InfoError.new($!,$@,@cf,@opt.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       ensure
       end
       begin
