@@ -87,7 +87,7 @@ module SiSU_EPUB
         unless @opt.cmd =~/q/
           tool=(@opt.cmd =~/[MVvz]/) \
           ? "#{@env.program.epub_viewer} #{@md.file.output_path.epub.dir}/#{@md.file.base_filename.epub}"
-          : "[#{@opt.f_pth[:lng_is]}] #{@opt.fns}"
+          : "[#{@opt.f_pth[:lng_is]}] #{@opt.fno}"
           @opt.cmd=~/[MVvz]/ \
           ? SiSU_Screen::Ansi.new(@opt.cmd,'EPUB',tool).green_hi_blue
           : SiSU_Screen::Ansi.new(@opt.cmd,'EPUB',tool).green_title_hi
@@ -107,7 +107,10 @@ module SiSU_EPUB
         scr_toc=SiSU_EPUB::Source::ScrollHeadAndSegToc.new(@md,toc).in_common #watch
         SiSU_EPUB::Source::Seg.new(@md,data).songsheet
         SiSU_EPUB::Source::Output.new(@md).songsheet
-      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       ensure
         unless @opt.cmd =~/[MV]/ #check maintenance flag
           texfiles=Dir["#{@env.processing_path.tune}/#{@opt.fns}*"]
@@ -302,7 +305,10 @@ module SiSU_EPUB
               begin
                 @@toc[:seg] << toc[:seg]
                 @@toc[:scr] << toc[:seg]
-              rescue; SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error
+              rescue
+                SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+                  __LINE__.to_s + ':' + __FILE__
+                end
               end
             end
           end
@@ -603,7 +609,10 @@ module SiSU_EPUB
             end
           end
           out.close
-        rescue; SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error
+        rescue
+          SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+            __LINE__.to_s + ':' + __FILE__
+          end
         end
       end
       def epub_metadata_opf
@@ -615,7 +624,10 @@ module SiSU_EPUB
             end
           end
           out.close
-        rescue; SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error
+        rescue
+          SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+            __LINE__.to_s + ':' + __FILE__
+          end
         end
       end
       def images
@@ -660,7 +672,10 @@ module SiSU_EPUB
             end
             filename_html_index.close
           end
-        rescue; SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error
+        rescue
+          SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+            __LINE__.to_s + ':' + __FILE__
+          end
         end
       end
     end
