@@ -140,7 +140,10 @@ WOK
         data=articles(data)
         SiSU_EPUB_Seg::Seg.new.cleanup # (((( added ))))
         #### (((( END )))) ####
-      rescue; SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       ensure
         @@seg_name=[]
       end
