@@ -216,7 +216,10 @@ module SiSU_EPUB_Tune
           SiSU_EPUB_Tune::Output.new(data,@md).marshal
         end
         tuned=SiSU_EPUB_Tune::Tune.new(@data,@md).output
-      rescue; SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       ensure
       end
     end
