@@ -63,10 +63,10 @@ module SiSU_Git
   class Source
     def initialize(opt)
       @opt=opt
-      @env=SiSU_Env::Info_env.new
+      @env=SiSU_Env::InfoEnv.new
       @md=SiSU_Param::Parameters.new(@opt).get
-      @file=SiSU_Env::SiSU_file.new(@md)
-      l=SiSU_Env::Standardise_language.new(@md.opt.lng).language
+      @file=SiSU_Env::FileOp.new(@md)
+      l=SiSU_Env::StandardiseLanguage.new(@md.opt.lng).language
       unless @opt.lng==l[:c] # @md.i18n[0]==l[:c]
         p "using: #{@opt.lng} (@make: :language:); filename #{@md.fns} filename language: #{l[:c]}, mismatch"
       end
@@ -197,7 +197,7 @@ module SiSU_Git
         end
       end
       def locate_skin
-        SiSU_Env::Info_skin.new(@md).select
+        SiSU_Env::InfoSkin.new(@md).select
       end
       def read_composite
         #print __FILE__ + ':'
