@@ -93,8 +93,8 @@ WOK
       case opt.mod.inspect
       when/--harvest/i
         css(opt) if opt.cmd.inspect =~/M/
-        SiSU_Harvest_Authors::Songsheet.new(opt,env).songsheet
-        SiSU_Harvest_Topics::Songsheet.new(opt,env).songsheet
+        SiSU_HarvestAuthors::Songsheet.new(opt,env).songsheet
+        SiSU_HarvestTopics::Songsheet.new(opt,env).songsheet
         if opt.cmd.inspect =~/R/
           require_relative 'remote'                         # remote.rb
           SiSU_Remote::Put.new(opt).rsync_harvest
