@@ -88,7 +88,7 @@ module SiSU_HTML
         loc=@env.url.output_tell
         unless @opt.cmd =~/q/
           tool=if @opt.cmd =~/[MVvz]/; "#{@env.program.web_browser} file://#{@md.file.output_path.html_seg.dir}/#{@md.file.base_filename.html_segtoc}"
-          else                          "[#{@opt.f_pth[:lng_is]}] #{@opt.fns}"
+          else                          "[#{@opt.f_pth[:lng_is]}] #{@opt.fno}"
           end
           @opt.cmd=~/[MVvz]/ \
           ? SiSU_Screen::Ansi.new(@opt.cmd,'HTML',tool).green_hi_blue
@@ -109,7 +109,10 @@ module SiSU_HTML
         scr=SiSU_HTML::Source::Scroll.new(@md,data,scr_endnotes).songsheet
         scroll=SiSU_HTML::Source::ScrollOutput.new(scr_toc,scr[:body],scr[:metadata],scr[:owner_details],scr[:tails],@md).publish
         SiSU_HTML::Source::Output.new(scroll,@md).scroll
-      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       ensure
         unless @opt.cmd =~/[MV]/ #check maintenance flag
           texfiles=Dir["#{@env.processing_path.tune}/#{@opt.fns}*"]
@@ -257,7 +260,10 @@ module SiSU_HTML
                 @@toc[:seg] << toc[:seg] if toc[:seg]
                 @@toc[:seg_mini] << toc[:seg_mini] if toc[:seg_mini]
                 @@toc[:scr] << toc[:scr] if toc[:scr]
-              rescue; SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error
+              rescue
+                SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+                  __LINE__.to_s + ':' + __FILE__
+                end
               end
             end
           end
@@ -626,8 +632,12 @@ WOK
               @filename_html_scroll.puts para,"\n"
             end
           end
-        rescue; SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error
-        ensure; @filename_html_scroll.close
+        rescue
+          SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+            __LINE__.to_s + ':' + __FILE__
+          end
+        ensure
+          @filename_html_scroll.close
         end
       end
       def segtoc
@@ -642,7 +652,10 @@ WOK
               @filename_html_segtoc.puts para,"\n"
             end
           end
-        rescue; SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error
+        rescue
+          SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+            __LINE__.to_s + ':' + __FILE__
+          end
         ensure
           @filename_html_segtoc.close
           pwd_set=Dir.pwd
