@@ -71,7 +71,10 @@ module SiSU_HTML_Scroll
         scr=SiSU_HTML_Scroll::Scroll.new(@md,@data,@endnotes).markup
         scr[:tails]=SiSU_HTML_Scroll::Scroll.new(@md).tails
         scr
-      rescue; SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       ensure
       end
     end
