@@ -242,7 +242,7 @@ also note ISO_639-2
 
 Px[:lng_lst] # constants.rb
 
-module SiSU_text_translation
+module SiSU_TextTranslation
   class Language
     def initialize(md)
       @md=md
