@@ -88,12 +88,15 @@ module SiSU_Manifest
           url_html="file://#{@md.file.output_path.manifest.dir}/#{@md.file.base_filename.manifest}"
           @opt.cmd=~/[MVvz]/ \
           ? SiSU_Screen::Ansi.new(@opt.cmd,'Manifest',"#{xbrowser} #{url_html}").green_hi_blue
-          : SiSU_Screen::Ansi.new(@opt.cmd,'Manifest',"[#{@opt.f_pth[:lng_is]}] #{@opt.fns}").green_title_hi
+          : SiSU_Screen::Ansi.new(@opt.cmd,'Manifest',"[#{@opt.f_pth[:lng_is]}] #{@opt.fno}").green_title_hi
           SiSU_Screen::Ansi.new(@opt.cmd,"#{browser} #{url_html}").grey_tab if @opt.cmd =~/v/i
         end
         data=SiSU_HTML::Source::HTML_Environment.new(@particulars).tuned_file_instructions
         SiSU_Manifest::Source::Output.new(@md).check_output(data)
-      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       ensure
       end
     end
@@ -890,7 +893,10 @@ WOK
 </html>
 WOK
           output
-        rescue; SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error
+        rescue
+          SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+            __LINE__.to_s + ':' + __FILE__
+          end
         ensure
         end
       end
