@@ -85,7 +85,7 @@ module SiSU_Manpage
         path=@env.path.output_tell
         tool=(@opt.cmd =~/[MVv]/) \
         ?  "#{@env.program.text_editor} #{@md.file.output_path.manpage.dir}/#{@md.file.base_filename.manpage}"
-        : "[#{@opt.f_pth[:lng_is]}] #{@opt.fns}"
+        : "[#{@opt.f_pth[:lng_is]}] #{@opt.fno}"
         @opt.cmd=~/[MVvz]/ \
         && @opt.cmd !~/q/ \
         ? SiSU_Screen::Ansi.new(@opt.cmd,'Manpage',tool).green_hi_blue
@@ -94,7 +94,10 @@ module SiSU_Manpage
         @dal_array=SiSU_DAL::Source.new(@opt).get # dal file drawn here
         SiSU_Manpage::Source::Scroll.new(@md,@dal_array).songsheet
         SiSU_Env::InfoSkin.new(@md).select #watch
-      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       ensure
       end
     end
