@@ -62,10 +62,10 @@ module SiSU_Commandline
   require_relative 'sysenv'                             # sysenv.rb
   @@base_path=nil
   class Options
-    attr_accessor :cmd,:mod,:act,:dir_structure_by,:f_pths,:files,:base_path,:base_stub,:sub_location,:paths,:lngs,:f_pth,:pth,:fns,:fnb,:fnc,:fncb,:lng,:lng_base,:what
+    attr_accessor :cmd,:mod,:act,:dir_structure_by,:f_pths,:files,:files_mod,:base_path,:base_stub,:sub_location,:paths,:lngs,:f_pth,:pth,:fno,:fns,:fnb,:fnc,:fncb,:lng,:lng_base,:what
     def initialize(a)
-      @cmd,@f_pth,@pth,@fns,@fnb,@fnc,@fncb,@what,@lng,@lng_base,@base_path,@base_stub,@sub_location='','','','','','','','','','','','',''
-      @f_pths,@files,@paths,@mod,@act=Array.new(5){[]}
+      @cmd,@f_pth,@pth,@fno,@fns,@fnb,@fnc,@fncb,@what,@lng,@lng_base,@base_path,@base_stub,@sub_location='','','','','','','','','','','','','',''
+      @f_pths,@files,@files_mod,@paths,@mod,@act=Array.new(5){[]}
       @env=SiSU_Env::InfoEnv.new
       @lng_base=@env.language_default_set
       @dir_structure_by=SiSU_Env::EnvCall.new.output_dir_structure.by?
@@ -397,14 +397,14 @@ module SiSU_Commandline
       end
       extra=''
       if cmd !~/[mn]/
-        extra+=if cmd =~/[abegHhIiNOoPpTtwXxyz]/ \
+        extra+=if cmd =~/[abegHhIiNOoPpQTtwXxyz]/ \
         and cmd !~/[mn]/
           'm'                        #% add dal
         elsif ((cmd =~/[Dd]/ \
         or (mod.inspect =~/--(?:(?:sq)?lite|pg(?:sql)?)/)) \
         and mod.inspect !~/(?:remove|(?:(?:re)?create(?:all)?|dropall|drop)$)/) \
         and cmd !~/[mn]/
-          'm'                                                                          #% add dal
+          'm'                        #% add dal
         else ''
         end
       end
@@ -416,17 +416,20 @@ module SiSU_Commandline
         end
       end
       if cmd !~/y/
-        extra+=if cmd =~/[abeHhIiNopsSstwXxz]/ \
+        extra+=if cmd =~/[abeHhIiNopQsSstwXxz]/ \
         and cmd !~/y/
-          'ym'            #% add manifest
+          'ym'                       #% add manifest
         elsif (cmd =~/[Dd]/ \
         or mod.inspect =~/--(?:(?:sq)?lite|pg(?:sql)?)/) \
         and files[0] !~/^remove$/ \
         and cmd !~/y/
-          'ym' #% add manifest
+          'ym'                       #% add manifest
         else ''
         end
       end
+      if cmd !~/u/                   #% add urls
+        extra+='u'
+      end
       cmd=cmd + extra
       cmds=cmd.scan(/CC|\S/)
       [cmds.uniq.join,mod]
@@ -448,6 +451,14 @@ module SiSU_Commandline
       else
         { bool: false, set: :na, inst: '' }
       end
+      act[:processing_path]=if mod.inspect =~/"--processing-path=/
+        base_pth=mod.join(';').gsub(/^.*--processing-path=['"]?(.+?)(?:['"]?;.+)?$/,'\1')
+        { bool: true, set: :on, inst: base_pth }
+      elsif mod.inspect =~/"--processing-path/
+        { bool: true, set: :on, inst: @base_path }
+      else
+        { bool: false, set: :na, inst: nil }
+      end
       act[:dump]=if mod.inspect =~/"--dump=/
         base_pth=mod.join(';').gsub(/^.*--dump=['"]?(.+?)(?:['"]?;.+)?$/,'\1')
         { bool: true, set: :on, inst: base_pth }
@@ -524,12 +535,15 @@ module SiSU_Commandline
       elsif mod.inspect =~/"--(?:exc|no)-manifest"/ \
       || act[:switch][:off].inspect =~/"manifest"/
         { bool: false, set: :off }
+      elsif act[:manifest]=(cmd =~/y/ \
+      || mod.inspect =~/"--manifest"/)
+        { bool: true, set: :on }
       else { bool: true, set: :na }
       end
       act[:links_to_manifest]=if mod.inspect =~/"--inc-links-to-manifest"|"--inc-manifest-links"/
         { bool: true, set: :on }
       elsif mod.inspect =~/"--(?:exc|no)-links-to-manifest"|"--(?:exc|no)-manifest-links"/ \
-      || act[:switch][:off].inspect =~/"links_to_manifest"|"manifest_links"/ \
+      || act[:switch][:off].inspect =~/"links_to_manifest"|"manifest_links"|"--(?:exc|no)-manifest"/ \
       || mod.inspect =~/"--(?:redirect|dump)/
         { bool: false, set: :off }
       else { bool: true, set: :na }
@@ -667,13 +681,13 @@ module SiSU_Commandline
       : { bool: false, set: :na }
       act[:sqlite]=(cmd =~/d/ \
       || mod.inspect =~/"--sqlite"/) \
-      && (mod.inspect =~/"--createdb"|"--create"|"--recreate"|"--dropall"|"--recreate"|"--import"|"--update"|"--remove"/) \
+      && (mod.inspect =~/"--createdb"|"--create(?:all)?"|"--dropall"|"--recreate(?:all)?"|"--import"|"--update"|"--remove"/) \
       ? { bool: true, set: :on }
       : { bool: false, set: :na }
       act[:sqlite_discreet]=(cmd =~/d/ \
       || mod.inspect =~/"--sql"|"--sqlite"/) \
       && (mod.inspect =~/"--both"/ \
-      || mod.inspect !~/"--createdb"|"--create"|"--recreate"|"--dropall"|"--recreate"|"--import"|"--update"|"--remove"/) \
+      || mod.inspect !~/"--createdb"|"--create(?:all)?"|"--dropall"|"--recreate(?:all)?"|"--import"|"--update"|"--remove"/) \
       ? { bool: true, set: :on }
       : { bool: false, set: :na }
       act[:harvest]=(mod.inspect =~/"--harvest"/) \
@@ -687,6 +701,10 @@ module SiSU_Commandline
       || mod.inspect =~/"--git"/) \
       ? { bool: true, set: :on }
       : { bool: false, set: :na }
+      act[:zap]=(cmd =~/Z/ \
+      || mod.inspect =~/"--zap"|"--delete"/) \
+      ? { bool: true, set: :on }
+      : { bool: false, set: :na }
       act[:hash_digests]=(cmd =~/N/ \
       || mod.inspect =~/"--hash-digests"/) \
       ? { bool: true, set: :on }
@@ -723,7 +741,7 @@ module SiSU_Commandline
       || mod.inspect =~/"--urls-all"/) \
       ? { bool: true, set: :on }
       : { bool: false, set: :na }
-      act[:urls_seleted]=(cmd =~/u/ \
+      act[:urls_selected]=(cmd =~/u/ \
       || mod.inspect =~/"--urls"/) \
       ? { bool: true, set: :on }
       : { bool: false, set: :na }
@@ -735,10 +753,6 @@ module SiSU_Commandline
       || mod.inspect =~/"--qrcode"/) \
       ? { bool: true, set: :on }
       : { bool: false, set: :na }
-      act[:manifest]=(cmd =~/y/ \
-      || mod.inspect =~/"--manifest"/) \
-      ? { bool: true, set: :on }
-      : { bool: false, set: :na }
       act[:help]=(mod.inspect =~/"--help/) \
       ? { bool: true, set: :on }
       : { bool: false, set: :na }
@@ -753,6 +767,11 @@ module SiSU_Commandline
     def act
       @act
     end
+    def files_mod
+      files_mod=files
+      @files_mod=files_mod
+      @files_mod
+    end
     def f_pth
       @f_pth
     end
@@ -768,6 +787,13 @@ module SiSU_Commandline
     def lng_base
       @lng_base
     end
+    def fno
+      @fno=if @fno and not @fno.empty?
+        @fno
+      else
+        fns[/(.+?(?:sst|ssm))(?:\.sst)?/,1]
+      end
+    end
     def fns
       @fns
     end
@@ -780,12 +806,14 @@ module SiSU_Commandline
       end
     end
     def fnc
-      @fnc=if @fns =~/\.(?:ssm\.sst|ssm)$/; fnb + '.ssm.sst'
+      @fnc=if @fns =~/\.(?:ssm\.sst|ssm)$/
+        fnb + '.ssm.sst'
       else @fns
       end
     end
     def fncb
-      @fncb=if @fns =~/(?:\~\S{2,3})?\.(?:ssm\.sst|ssm)$/; fnb + '.ssm.sst'
+      @fncb=if @fns =~/(?:\~\S{2,3})?\.(?:ssm\.sst|ssm)$/
+        fnb + '.ssm.sst'
       else @fns.gsub(/(?:\~\S{2,3})?(\.sst)$/,'\1')
       end
     end
