@@ -132,7 +132,10 @@ module SiSU_Particulars
       begin
         @md=SiSU_Param::Parameters.new(@opt).get
         self
-      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       end
     end
     attr_accessor :opt,:env,:file
@@ -140,7 +143,10 @@ module SiSU_Particulars
       begin
         @env=SiSU_Env::InfoEnv.new(@opt.fns)
         self
-      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       end
     end
     def set_file
@@ -148,43 +154,61 @@ module SiSU_Particulars
         set_md unless @md
         @file=SiSU_Env::FileOp.new(@md)
         self
-      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       end
     end
     attr_accessor :opt,:dal_array
     def set_dal
       begin
-        @dal_array=@dal_array=SiSU_DAL::Source.new(@md).get
+        @dal_array=SiSU_DAL::Source.new(@opt).get
         self
-      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       end
     end
     def set_sst_idx
       begin
-        @sst_idx=SiSU_DAL::Source.new(@md).get_idx_sst
+        @sst_idx=SiSU_DAL::Source.new(@opt).get_idx_sst
         self
-      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       end
     end
     def set_tex_idx
       begin
-        @tex_idx=SiSU_DAL::Source.new(@md).get_idx_tex
+        @tex_idx=SiSU_DAL::Source.new(@opt).get_idx_tex
         self
-      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       end
     end
     def set_html_idx
       begin
-        @html_idx=SiSU_DAL::Source.new(@md).get_idx_html
+        @html_idx=SiSU_DAL::Source.new(@opt).get_idx_html
         self
-      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       end
     end
     def set_xhtml_idx
       begin
-        @xhtml_idx=SiSU_DAL::Source.new(@md).get_idx_xhtml
+        @xhtml_idx=SiSU_DAL::Source.new(@opt).get_idx_xhtml
         self
-      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       end
     end
     attr_accessor :nametags_map
@@ -193,7 +217,10 @@ module SiSU_Particulars
         opt=@md ? @md : @opt
         @nametags_map=SiSU_DAL::Source.new(opt).get_map_nametags
         self
-      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       end
     end
     attr_accessor :ocn_htmlseg_map
@@ -201,7 +228,10 @@ module SiSU_Particulars
       begin
         @ocn_htmlseg_map=SiSU_DAL::Source.new(@md).get_map_ocn_htmlseg
         self
-      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       end
     end
   end
