@@ -85,7 +85,7 @@ module SiSU_Plaintext
           path=env.path.output_tell
           tool=(@opt.cmd =~/[MVv]/) \
           ? "#{env.program.text_editor} #{md.file.output_path.txt.dir}/#{md.file.base_filename.txt}"
-          : "[#{@opt.f_pth[:lng_is]}] #{@opt.fns}"
+          : "[#{@opt.f_pth[:lng_is]}] #{@opt.fno}"
           @opt.cmd=~/[MVvz]/ \
           ? SiSU_Screen::Ansi.new(@opt.cmd,'Plaintext',tool).green_hi_blue
           : SiSU_Screen::Ansi.new(@opt.cmd,'Plaintext',tool).green_title_hi
