@@ -77,7 +77,7 @@ module SiSU_Po4a
       r=r.gsub(/\|en\|/,'|')
       @lang_regx=%r{(?:#{r})}
       if opt.fns =~/\S+?~#{@lang_regx}\.ss[mti]/ \
-      and opt.f_pth[:lng]!=opt.lng_base
+      and opt.f_pth[:lng]!=@opt.lng_base
         @@opt_src_=false
         @@opt_trn=opt
         @@md_trn=SiSU_Param::Parameters.new(opt).get
@@ -114,7 +114,7 @@ module SiSU_Po4a
             SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"#{path}/#{md.fnb}/#{md.fn[:plain]}").flow if @opt.cmd =~/[MV]/
           end
           if @opt.fns =~/\S+?~#{@lang_regx}\.ss[mti]/ \
-          or @opt.f_pth[:lng] !=opt.lng_base
+          or @opt.f_pth[:lng] !=@opt.lng_base
             opt_lang_trn_fn=fn
             @dal_array_lang_translation=SiSU_DAL::Source.new(@opt,opt_lang_trn_fn).get # dal file drawn here
             opt_lang_src_fn=if fn =~/\S+?~\S{2}(?:_\S{2})?\.ss[mti]/
@@ -124,7 +124,7 @@ module SiSU_Po4a
             transdir,srcdir=Dir.pwd,Dir.pwd
             if Dir.pwd.to_s =~/\/#{@lang_regx}$/
               transdir=Dir.pwd
-              srcdir=transdir.gsub(/\/#{@lang_regx}$/,"/#{opt.lng_base}")
+              srcdir=transdir.gsub(/\/#{@lang_regx}$/,"/#{@opt.lng_base}")
               if FileTest.directory?(srcdir)
                  Dir.chdir(srcdir)
               end
@@ -152,7 +152,10 @@ module SiSU_Po4a
           SiSU_Po4a::Source::Scroll.new(fn,@dal_array_lang_src,@dal_array_lang_translation,@@md_src,@@md_trn,wrap_width).songsheet
           SiSU_Env::InfoSkin.new(md).select #watch
         end
-      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       ensure
       end
     end
@@ -926,7 +929,7 @@ GSUB
         @file=SiSU_Env::FileOp.new(md,fn)
       end
       def po4a                                                                #%pot output
-        file_pot=(@md.opt.f_pth[:lng] ==opt.lng_base) \
+        file_pot=(@md.opt.f_pth[:lng] ==@md.opt.lng_base) \
         ? @file.write_file.pot
         : @file.write_file.po
         @sisu=[]
@@ -957,7 +960,7 @@ GSUB
           require_relative 'git'                           # git.rb
           git=SiSU_Git::Source.new(@md.opt)
           git.create_file_structure_git unless FileTest.directory?(@file.output_path.pot_git.dir)
-          if @md.opt.f_pth[:lng] ==opt.lng_base
+          if @md.opt.f_pth[:lng] ==@md.opt.lng_base
             FileUtils::cp(@file.place_file.pot.dir, @file.output_path.pot_git.dir)
           else # naive, work on -->
             FileUtils::cp(@file.place_file.po.dir, @file.output_path.po_git.dir) #unless FileTest.file?(@file.place_file.po_git.dir)
