@@ -68,8 +68,8 @@ module SiSU_Rexml
     require 'rexml/document' if FileTest.directory?("#{Config::CONFIG['rubylibdir']}/rexml") #Config::CONFIG['sitedir']
     def initialize(md,fno)
       @md,@fno=md,fno
-      @env=SiSU_Env::Info_env.new(@md.fns)
-      @prog=SiSU_Env::Info_program.new #(md.fns) #if md
+      @env=SiSU_Env::InfoEnv.new(@md.fns)
+      @prog=SiSU_Env::InfoProgram.new #(md.fns) #if md
       if File.file?(@fno)
         @fnap=@fno #index.xml causes problems with index.html in server config
       end
@@ -102,7 +102,7 @@ module SiSU_Rexml
           SiSU_Screen::Ansi.new(@md.opt.cmd,'fuschia',"File Not Found #{xmlfile}",'requested XML processing skipped').colorize unless @md.opt.cmd =~/q/
           exit
         end
-      rescue; SiSU_Errors::Info_error.new($!,$@,@md.opt.cmd,@md.fns).error
+      rescue; SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error
       ensure
       end
     end
