@@ -56,7 +56,7 @@
  ** Description: share sisu source markup file, copy it to output directory!
 
 =end
-module SiSU_Kdi_source
+module SiSU_KdiSource
   require_relative 'sysenv'                             # sysenv.rb
     include SiSU_Env
   pwd=Dir.pwd
@@ -65,7 +65,7 @@ module SiSU_Kdi_source
       include FileUtils
     def initialize(opt)
       @opt=opt
-      @env=SiSU_Env::Info_env.new(@opt.fns)
+      @env=SiSU_Env::InfoEnv.new(@opt.fns)
       @output_path="#{@env.path.output}/#{@opt.fnb}"
     end
     def read
