@@ -355,7 +355,7 @@ module SiSU_Metadata
         def texpdf_font
           if defined? @md.make.texpdf_font \
           and @md.make.texpdf_font
-            ' :texpdf_font: ' + @md.make.texpdf_font
+            ' :texpdf_font: ' + @md.make.texpdf_font.main
           else nil
           end
         end
