@@ -62,7 +62,7 @@ module SiSU_Modify
   require_relative 'sst_identify_markup'                # sst_identify_markup.rb
   require_relative 'sst_from_xml'                       # sst_from_xml.rb
   require_relative 'response'                           # response.rb
-  class Convert_markup
+  class ConvertMarkup
     def initialize(opt)
       @opt=opt
       @description='This is a script that contains canned text conversions for reuse'
@@ -173,7 +173,7 @@ WOK
       end
     end
     def convert_to_simple_xml_model_sax
-      SiSU_simple_xml_model_sax::Convert.new(@opt).read
+      SiSU_SimpleXML_ModelSax::Convert.new(@opt).read
     end
     def convert_to_simple_xml_model_dom
       SiSU_simple_xml_model_dom::Convert.new(@opt).read
@@ -185,11 +185,11 @@ WOK
       SiSU_Kdissert::Convert.new(@opt).read
     end
     def convert_s_xml_to_sst
-      SiSU_sst_from_xml::Convert.new(@opt).read
+      SiSU_sstFromXML::Convert.new(@opt).read
     end
     def convert_footnotes
       require_relative 'sst_do_inline_footnotes'
-      SiSU_Convert_footnotes::Source.new(@opt).read
+      SiSU_ConvertFootnotes::Source.new(@opt).read
     end
     def conversion
       #%% do it                                   -------------------------->
@@ -231,7 +231,7 @@ WOK
           if i =~/(?:\.sst|\.ssm|\.ssi)$/
             @new,@matched,@flag_start,@flag_end,@empty1,@empty2=true,false,false,false,false,false
             o="#{i}.bk" #o is for old
-            markup_version=SiSU_Markup::Markup_identify.new(@opt).markup_version?
+            markup_version=SiSU_Markup::MarkupIdentify.new(@opt).markup_version?
             if (@opt.mod.inspect=~/37/ and markup_version=~/0.38/) \
             or (@opt.mod.inspect=~/current|38/ and markup_version=~/0.37/)
               puts "#{i} #{markup_version}"
@@ -296,17 +296,17 @@ end
 #%% files to match for this conversion set  ------------------------->
 require_relative 'options'                              # options.rb
 argv=$*
-@opt=SiSU_commandline::Options.new(argv)
+@opt=SiSU_Commandline::Options.new(argv)
 case @opt.mod.inspect
 when /=kdi/
-  SiSU_Modify::Convert_markup.new(@opt).conversion
+  SiSU_Modify::ConvertMarkup.new(@opt).conversion
 when /(?:36|37|38)?to-?(?:37|38)|--convert|--to|--from|default/
 @opt.files.each do |fns|
   @opt.fns=fns
-  SiSU_Modify::Convert_markup.new(@opt).conversion
+  SiSU_Modify::ConvertMarkup.new(@opt).conversion
 end
 else
   @opt.mod='--help'
- SiSU_Modify::Convert_markup.new(@opt).help
+ SiSU_Modify::ConvertMarkup.new(@opt).help
 end
 __END__
