@@ -102,7 +102,7 @@ module SiSU_TexInfo
       begin
         tool=(@opt.cmd =~/[MVv]/) \
         ?  "#{@env.program.texinfo} #{@md.file.output_path.texinfo.dir}/#{@md.file.base_filename.info}"
-        : "[#{@opt.f_pth[:lng_is]}] #{@opt.fns}"
+        : "[#{@opt.f_pth[:lng_is]}] #{@opt.fno}"
         tell=@opt.cmd=~/[MVvz]/ \
         && @opt.cmd !~/q/ \
         ? SiSU_Screen::Ansi.new(@opt.cmd,'TexInfo',tool).green_hi_blue
