@@ -94,7 +94,10 @@ module SiSU_TeX
           SiSU_Env::FileOp.new(@md).mkdir
           Dir.mkdir(@env.processing_path.tex) unless FileTest.directory?(@env.processing_path.tex)
         end
-      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       ensure
       end
     end
@@ -104,7 +107,7 @@ module SiSU_TeX
     def song
       begin
         @md=@particulars.md
-        SiSU_Screen::Ansi.new(@opt.cmd,'LaTeX/PDF',"[#{@opt.f_pth[:lng_is]}] #{@opt.fns}").green_title_hi unless @opt.cmd =~/q/
+        SiSU_Screen::Ansi.new(@opt.cmd,'LaTeX/PDF',"[#{@opt.f_pth[:lng_is]}] #{@opt.fno}").green_title_hi unless @opt.cmd =~/q/
         if @opt.cmd =~/[MVv]/
           path=@env.url.output_tell
           SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"#{@env.program.pdf_viewer} #{@md.file.output_path.pdf.dir}/#{@md.file.base_filename.pdf_l}pdf").flow
@@ -121,7 +124,10 @@ module SiSU_TeX
         pwd=Dir.pwd
         SiSU_TeX::Source::LaTeXtoPdf.new(@md,@particulars.env).latexrun_selective
         Dir.chdir(pwd)
-      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       ensure
         unless @opt.cmd =~/[MV]/ #check maintenance flag
           texfiles=Dir["#{@env.processing_path.tex}/#{@opt.fns}*"]
@@ -261,7 +267,10 @@ module SiSU_TeX
           end
           lst=Dir["*.{aux,log,out}"]
           lst.each {|file| File.unlink(file)} if lst
-        rescue; SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error
+        rescue
+          SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+            __LINE__.to_s + ':' + __FILE__
+          end
         end
       end
     end
@@ -322,7 +331,10 @@ module SiSU_TeX
           data=number_paras(data)
           data=markup(data)
           output(data)
-        rescue; SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error
+        rescue
+          SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+            __LINE__.to_s + ':' + __FILE__
+          end
         ensure
         end
       end
