@@ -69,7 +69,10 @@ module SiSU_Urls
     def read
       begin
         SiSU_Urls::OutputUrls.new(@opt).songsheet if @opt.fnb
-      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@opt.cmd).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       ensure
       end
     end
@@ -123,7 +126,10 @@ module SiSU_Urls
     def songsheet
       begin
        @opt.cmd=~/U/ ? urls_all : (urls_select unless @opt.cmd=~/q/)
-      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       ensure
       end
     end
@@ -159,14 +165,14 @@ module SiSU_Urls
         def concordance(x)
           SiSU_Screen::Ansi.new(@opt.cmd,"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.html_concordance.dir}/#{@md.file.base_filename.html_concordance}").result
         end
-        def qrcode(x)
-          SiSU_Screen::Ansi.new(@opt.cmd,"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.manifest.dir}/#{@md.file.base_filename.manifest}").result
-        end
         def manifest(x)
           SiSU_Screen::Ansi.new(@opt.cmd,"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.manifest.dir}/#{@md.file.base_filename.manifest}").result
         end
         self
       end
+      def qrcode(x)
+        SiSU_Screen::Ansi.new(@opt.cmd,"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.manifest.dir}/#{@md.file.base_filename.manifest}").result
+      end
       def odt(x)
         SiSU_Screen::Ansi.new(@opt.cmd,"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.odf_viewer} file://#{@md.file.output_path.odt.dir}/#{@md.file.base_filename.odt}").result
       end
