@@ -87,7 +87,7 @@ module SiSU_XHTML
             "#{@env.program.web_browser} file://#{@md.file.output_path.xhtml.dir}/#{@md.file.base_filename.xhtml}"
           elsif @opt.cmd =~/v/
             "#{@env.program.web_browser} file://#{@md.file.output_path.xhtml.dir}/#{@md.file.base_filename.xhtml}"
-          else "[#{@opt.f_pth[:lng_is]}] #{@opt.fns}"
+          else "[#{@opt.f_pth[:lng_is]}] #{@opt.fno}"
           end
           @opt.cmd=~/[MVvz]/ \
           ? SiSU_Screen::Ansi.new(@opt.cmd,'invert','XHTML',tool).colorize
@@ -95,7 +95,10 @@ module SiSU_XHTML
           SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"/#{@md.file.output_path.xhtml.dir}/#{@md.file.base_filename.xhtml}").flow if @opt.cmd =~/[MV]/
         end
         SiSU_XHTML::Source::Songsheet.new(@particulars).song
-      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       ensure
       end
     end
@@ -110,7 +113,10 @@ module SiSU_XHTML
           SiSU_XHTML::Source::Scroll.new(@particulars).songsheet
           SiSU_XHTML::Source::Tidy.new(@md,@file.place_file.xhtml.dir).xml if @md.opt.cmd =~/[vVM]/ # test wellformedness, comment out when not in use
           SiSU_Rexml::Rexml.new(@md,@file.place_file.xhtml.dir).xml if @md.opt.cmd =~/M/ # test rexml parsing, comment out when not in use #debug
-        rescue; SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error
+        rescue
+          SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+            __LINE__.to_s + ':' + __FILE__
+          end
         ensure
         end
       end
