@@ -73,7 +73,10 @@ module SiSU_XML_Scaffold
       begin
         @md,@dal_array=@particulars.md,@particulars.dal_array
         SiSU_XML_Scaffold::Source::Scroll.new(@dal_array,@md).songsheet
-      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       ensure
       end
     end
