@@ -63,12 +63,12 @@ module SiSU_Zap
   class Source
     def initialize(opt)
       @opt=opt
-      @env=SiSU_Env::Info_env.new(@opt.fns)
+      @env=SiSU_Env::InfoEnv.new(@opt.fns)
       @zap_path="#{@env.path.output}/#{@env.fnb}"
-      @zap=SiSU_Env::Clean_output.new(@opt)
+      @zap=SiSU_Env::CleanOutput.new(@opt)
     end
     def read
-      if SiSU_Env::Info_settings.new.permission?('zap')
+      if SiSU_Env::InfoSettings.new.permission?('zap')
         tell=SiSU_Screen::Ansi.new(@opt.cmd,"Clean files related to processing #{@opt.cmd} ->","#{@opt.fns} -> #{@zap_path}")
         @zap.zap.main_output
         @zap.zap.site_map
